==> qbittorrent_5.0.4.orig.tar.xz: qbittorrent-5.0.4/src/base/bittorrent/trackerentrystatus.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2015-2023  Vladimir Golovnev <glassez@yandex.ru>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#pragma once

#include <QDateTime>
#include <QHash>
#include <QString>

class QStringView;

namespace BitTorrent
{
    enum class TrackerEndpointState
    {
        NotContacted = 1,
        Working = 2,
        Updating = 3,
        NotWorking = 4,
        TrackerError = 5,
        Unreachable = 6
    };

    struct TrackerEndpointStatus
    {
        QString name {};
        int btVersion = 1;

        TrackerEndpointState state = TrackerEndpointState::NotContacted;
        QString message {};

        int numPeers = -1;
        int numSeeds = -1;
        int numLeeches = -1;
        int numDownloaded = -1;

        QDateTime nextAnnounceTime {};
        QDateTime minAnnounceTime {};
    };

    struct TrackerEntryStatus
    {
        QString url {};
        int tier = 0;

        TrackerEndpointState state = TrackerEndpointState::NotContacted;
        QString message {};

        int numPeers = -1;
        int numSeeds = -1;
        int numLeeches = -1;
        int numDownloaded = -1;

        QDateTime nextAnnounceTime {};
        QDateTime minAnnounceTime {};

        QHash<std::pair<QString, int>, TrackerEndpointStatus> endpoints {};

        void clear();
    };

    bool operator==(const TrackerEntryStatus &left, const TrackerEntryStatus &right);
    std::size_t qHash(const TrackerEntryStatus &key, std::size_t seed = 0);
}

==> qbittorrent_5.1.0.orig.tar.xz: qbittorrent-5.1.0/src/base/bittorrent/trackerentrystatus.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2015-2024  Vladimir Golovnev <glassez@yandex.ru>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#pragma once

#include <QHash>
#include <QString>

#include "announcetimepoint.h"

class QStringView;

namespace BitTorrent
{
    enum class TrackerEndpointState
    {
        NotContacted = 1,
        Working = 2,
        Updating = 3,
        NotWorking = 4,
        TrackerError = 5,
        Unreachable = 6
    };

    struct TrackerEndpointStatus
    {
        QString name {};
        int btVersion = 1;

        TrackerEndpointState state = TrackerEndpointState::NotContacted;
        QString message {};

        int numPeers = -1;
        int numSeeds = -1;
        int numLeeches = -1;
        int numDownloaded = -1;

        AnnounceTimePoint nextAnnounceTime {};
        AnnounceTimePoint minAnnounceTime {};
    };

    struct TrackerEntryStatus
    {
        QString url {};
        int tier = 0;

        TrackerEndpointState state = TrackerEndpointState::NotContacted;
        QString message {};

        int numPeers = -1;
        int numSeeds = -1;
        int numLeeches = -1;
        int numDownloaded = -1;

        AnnounceTimePoint nextAnnounceTime {};
        AnnounceTimePoint minAnnounceTime {};

        QHash<std::pair<QString, int>, TrackerEndpointStatus> endpoints {};

        void clear();
    };

    bool operator==(const TrackerEntryStatus &left, const TrackerEntryStatus &right);
    std::size_t qHash(const TrackerEntryStatus &key, std::size_t seed = 0);
}
